==> prison-kf5-5.103.0.tgz: include/KF5/Prison/Prison/prison_export.h <==

#ifndef PRISON_EXPORT_H
#define PRISON_EXPORT_H

#ifdef PRISON_STATIC_DEFINE
#  define PRISON_EXPORT
#  define PRISON_NO_EXPORT
#else
#  ifndef PRISON_EXPORT
#    ifdef KF5Prison_EXPORTS
        /* We are building this library */
#      define PRISON_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PRISON_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PRISON_NO_EXPORT
#    define PRISON_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PRISON_DECL_DEPRECATED
#  define PRISON_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DECL_DEPRECATED_EXPORT PRISON_EXPORT PRISON_DECL_DEPRECATED
#endif

#ifndef PRISON_DECL_DEPRECATED_NO_EXPORT
#  define PRISON_DECL_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT PRISON_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PRISON_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  endif
#endif

#define PRISON_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(PRISON_NO_DEPRECATED) && !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(PRISON_NO_DEPRECATED_WARNINGS) && !defined(PRISON_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define PRISON_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(PRISON_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(PRISON_NO_DEPRECATED)
#  undef PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#elif defined(PRISON_NO_DEPRECATED_WARNINGS)
#  define PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#else
#  define PRISON_DEPRECATED PRISON_DECL_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PRISON_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PRISON_NO_DEPRECATED
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
#endif
#ifdef PRISON_NO_DEPRECATED_WARNINGS
#  define PRISON_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PRISON_DEPRECATED_WARNINGS_SINCE
#  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x56700
#  endif
#endif

#ifndef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef PRISON_DEPRECATED
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if PRISON_DEPRECATED_WARNINGS_SINCE >= 0x54500
#  define PRISON_DEPRECATED_VERSION_5_69(text) PRISON_DECL_DEPRECATED_TEXT(text)
#else
#  define PRISON_DEPRECATED_VERSION_5_69(text)
#endif

#if PRISON_DEPRECATED_WARNINGS_SINCE >= 0x54800
#  define PRISON_DEPRECATED_VERSION_5_72(text) PRISON_DECL_DEPRECATED_TEXT(text)
#else
#  define PRISON_DEPRECATED_VERSION_5_72(text)
#endif
#define PRISON_DEPRECATED_VERSION_5(minor, text)      PRISON_DEPRECATED_VERSION_5_##minor(text)
#define PRISON_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION(major, minor, text)
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* PRISON_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_PRISON_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_PRISON_EXPORT_H


#define PRISON_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(PRISON_NO_DEPRECATED) && !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(PRISON_NO_DEPRECATED_WARNINGS) && !defined(PRISON_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define PRISON_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(PRISON_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(PRISON_NO_DEPRECATED)
#  undef PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#elif defined(PRISON_NO_DEPRECATED_WARNINGS)
#  define PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#else
#  define PRISON_DEPRECATED PRISON_DECL_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PRISON_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PRISON_NO_DEPRECATED
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
#endif
#ifdef PRISON_NO_DEPRECATED_WARNINGS
#  define PRISON_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PRISON_DEPRECATED_WARNINGS_SINCE
#  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x56700
#  endif
#endif

#ifndef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef PRISON_DEPRECATED
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if PRISON_DEPRECATED_WARNINGS_SINCE >= 0x54500
#  define PRISON_DEPRECATED_VERSION_5_69(text) PRISON_DECL_DEPRECATED_TEXT(text)
#else
#  define PRISON_DEPRECATED_VERSION_5_69(text)
#endif

#if PRISON_DEPRECATED_WARNINGS_SINCE >= 0x54800
#  define PRISON_DEPRECATED_VERSION_5_72(text) PRISON_DECL_DEPRECATED_TEXT(text)
#else
#  define PRISON_DEPRECATED_VERSION_5_72(text)
#endif
#define PRISON_DEPRECATED_VERSION_5(minor, text)      PRISON_DEPRECATED_VERSION_5_##minor(text)
#define PRISON_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION(major, minor, text)
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_PRISON_EXPORT_H */

==> prison-kf5-5.116.0.tgz: include/KF5/Prison/Prison/prison_export.h <==

#ifndef PRISON_EXPORT_H
#define PRISON_EXPORT_H

#ifdef PRISON_STATIC_DEFINE
#  define PRISON_EXPORT
#  define PRISON_NO_EXPORT
#else
#  ifndef PRISON_EXPORT
#    ifdef KF5Prison_EXPORTS
        /* We are building this library */
#      define PRISON_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PRISON_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PRISON_NO_EXPORT
#    define PRISON_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PRISON_DECL_DEPRECATED
#  define PRISON_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DECL_DEPRECATED_EXPORT PRISON_EXPORT PRISON_DECL_DEPRECATED
#endif

#ifndef PRISON_DECL_DEPRECATED_NO_EXPORT
#  define PRISON_DECL_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT PRISON_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PRISON_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  endif
#endif

#define PRISON_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(PRISON_NO_DEPRECATED) && !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define PRISON_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(PRISON_NO_DEPRECATED_WARNINGS) && !defined(PRISON_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define PRISON_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(PRISON_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define PRISON_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(PRISON_NO_DEPRECATED)
#  undef PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#elif defined(PRISON_NO_DEPRECATED_WARNINGS)
#  define PRISON_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_NO_EXPORT
#else
#  define PRISON_DEPRECATED PRISON_DECL_DEPRECATED
#  define PRISON_DEPRECATED_EXPORT PRISON_DECL_DEPRECATED_EXPORT
#  define PRISON_DEPRECATED_NO_EXPORT PRISON_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PRISON_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PRISON_NO_DEPRECATED
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
#endif
#ifdef PRISON_NO_DEPRECATED_WARNINGS
#  define PRISON_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PRISON_DEPRECATED_WARNINGS_SINCE
#  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x57400
#  endif
#endif

#ifndef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef PRISON_DEPRECATED
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PRISON_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if PRISON_DEPRECATED_WARNINGS_SINCE >= 0x54500
#  define PRISON_DEPRECATED_VERSION_5_69(text) PRISON_DECL_DEPRECATED_TEXT(text)
#else
#  define PRISON_DEPRECATED_VERSION_5_69(text)
#endif

#if PRISON_DEPRECATED_WARNINGS_SINCE >= 0x54800
#  define PRISON_DEPRECATED_VERSION_5_72(text) PRISON_DECL_DEPRECATED_TEXT(text)
#else
#  define PRISON_DEPRECATED_VERSION_5_72(text)
#endif
#define PRISON_DEPRECATED_VERSION_5(minor, text)      PRISON_DEPRECATED_VERSION_5_##minor(text)
#define PRISON_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION(major, minor, text)
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* PRISON_EXPORT_H */
